@@ -436,21 +436,29 @@ bool do_operation_export(const QStringList args){
         usage_export();
         return false;
     } else {
-        cout << "will export calendar with id:" << calendar_id << endl;
+        //cout << "will export calendar with id:" << calendar_id << endl;
+        log("will export calendar with id:", 1, false );
+        log(QString::number(calendar_id).toLocal8Bit().constData(),1,true);
+
     }
 
     if(!parse_cmd_arg_filename(args, filename)){
-        cout << "file was not specified:" << filename.toAscii().constData() << endl;
+        //cout << "file was not specified:" << filename.toAscii().constData() << endl;
+        log("file was not specified:",1,false);
+        log(filename.toAscii().constData(),1,true);
         filename = calendar.append(".ics");
     }
 
     int errcode = 0;
     int result = 99;
-    cout << "calendar will be exported to:" << filename.toAscii().constData() << endl;
+    //cout << "calendar will be exported to:" << filename.toAscii().constData() << endl;
+    log("calendar will be exported to:",1,false);
+    log(filename.toAscii().constData(),1,true);
     result = mcalendar->exportCalendarEntries(calendar_id, filename.toAscii().constData(),errcode);
 
     if(errcode == CALENDAR_OPERATION_SUCCESSFUL){
-        cout << "The calendar was successfully exported." << endl;
+        //cout << "The calendar was successfully exported." << endl;
+        log("The calendar was successfully exported.",1,true);
         return true;
     } else {
         switch (errcode){
@@ -461,7 +469,7 @@ bool do_operation_export(const QStringList args){
 
         return false;
     }
-    \
+
 }
 
 bool do_operation_tasks_clear_done(const QStringList args){
